zh_country = [
    "阿富汗",
    "阿尔巴尼亚",
    "阿尔及利亚",
    "美属萨摩亚",
    "安道尔",
    "安哥拉",
    "安圭拉岛",
    "南极洲",
    "安提瓜和巴布达",
    "阿根廷",
    "亚美尼亚",
    "阿鲁巴岛",
    "澳大利亚",
    "奥地利",
    "阿塞拜疆",
    "巴哈马",
    "巴林",
    "孟加拉国",
    "巴巴多斯",
    "白俄罗斯",
    "比利时",
    "伯利兹",
    "贝宁",
    "百慕大",
    "不丹",
    "玻利维亚",
    "波斯尼亚和黑塞哥维那",
    "博茨瓦纳",
    "巴西",
    "英属印度洋领地",
    "英属维尔京群岛",
    "文莱",
    "保加利亚",
    "布基纳法索",
    "缅甸",
    "布隆迪",
    "柬埔寨",
    "喀麦隆",
    "加拿大",
    "佛得角",
    "开曼群岛",
    "中非共和国",
    "乍得",
    "智利",
    "中国",
    "圣诞岛",
    "克利珀顿岛",
    "科科斯（基林）群岛",
    "哥伦比亚",
    "科摩罗",
    "刚果民主共和国",
    "刚果共和国",
    "库克群岛",
    "珊瑚海群岛",
    "哥斯达黎加",
    "科特迪瓦",
    "克罗地亚",
    "古巴",
    "塞浦路斯",
    "捷克共和国",
    "丹麦",
    "吉布地",
    "多米尼克",
    "多明尼加共和国",
    "厄瓜多尔",
    "埃及",
    "萨尔瓦多",
    "赤道几内亚",
    "厄立特里亚",
    "爱沙尼亚",
    "埃塞俄比亚",
    "欧罗巴岛",
    "福克兰群岛",
    "法罗群岛",
    "斐济",
    "芬兰",
    "法国",
    "法属圭亚那",
    "法属波利尼西亚",
    "加蓬",
    "冈比亚",
    "乔治亚",
    "德国",
    "加纳",
    "直布罗陀",
    "格洛里厄斯群岛",
    "希腊",
    "格陵兰",
    "格林纳达",
    "瓜德罗普岛",
    "关岛",
    "危地马拉",
    "根西岛",
    "几内亚",
    "几内亚比绍",
    "圭亚那",
    "海地",
    "罗马教廷（梵蒂冈城）",
    "洪都拉斯",
    "匈牙利",
    "冰岛",
    "印度",
    "印度尼西亚",
    "伊朗",
    "伊拉克",
    "爱尔兰",
    "马恩岛",
    "以色列",
    "意大利",
    "牙买加",
    "扬马延岛",
    "日本",
    "泽西岛",
    "约旦",
    "新胡安岛",
    "哈萨克斯坦",
    "肯尼亚",
    "基里巴斯",
    "科威特",
    "吉尔吉斯斯坦",
    "老挝",
    "拉脱维亚",
    "黎巴嫩",
    "莱索托",
    "利比里亚",
    "利比亚",
    "列支敦士登",
    "立陶宛",
    "卢森堡",
    "马其顿",
    "马达加斯加",
    "马拉维",
    "马来西亚",
    "马尔代夫",
    "马里",
    "马耳他",
    "马绍尔群岛",
    "马提尼克岛",
    "毛里塔尼亚",
    "毛里求斯",
    "马约特岛",
    "墨西哥",
    "密克罗尼西亚联邦",
    "摩尔多瓦",
    "摩纳哥",
    "蒙古",
    "蒙特塞拉特",
    "摩洛哥",
    "莫桑比克",
    "纳米比亚",
    "瑙鲁",
    "纳瓦萨岛",
    "尼泊尔",
    "荷兰",
    "荷属安的列斯",
    "新喀里多尼亚",
    "新西兰",
    "尼加拉瓜",
    "尼日尔",
    "尼日利亚",
    "纽埃",
    "诺福克岛",
    "朝鲜",
    "北马里亚纳群岛",
    "挪威",
    "阿曼",
    "巴基斯坦",
    "帕劳",
    "巴拿马",
    "巴布亚新几内亚",
    "西沙群岛",
    "巴拉圭",
    "秘鲁",
    "菲律宾",
    "皮特凯恩群岛",
    "波兰",
    "葡萄牙",
    "波多黎各",
    "卡塔尔",
    "留尼汪",
    "罗马尼亚",
    "俄罗斯",
    "卢旺达",
    "圣赫勒拿岛",
    "圣基茨和尼维斯",
    "圣卢西亚岛",
    "圣皮埃尔和密克隆群岛",
    "圣文森特和格林纳丁斯",
    "萨摩亚",
    "圣马力诺",
    "圣多美和普林西比",
    "沙特阿拉伯",
    "塞内加尔",
    "塞尔维亚和黑山",
    "塞舌尔群岛",
    "塞拉利昂",
    "新加坡",
    "斯洛伐克",
    "斯洛文尼亚",
    "所罗门群岛",
    "索马里",
    "南非",
    "韩国",
    "西班牙",
    "南沙群岛",
    "斯里兰卡",
    "苏丹",
    "苏里南",
    "斯瓦尔巴群岛",
    "斯威士兰",
    "瑞典",
    "瑞士",
    "叙利亚",
    "塔吉克斯坦",
    "坦桑尼亚",
    "泰国",
    "东帝汶",
    "多哥",
    "托克劳",
    "汤加",
    "特立尼达和多巴哥",
    "特罗姆兰岛",
    "突尼斯",
    "土耳其",
    "土库曼斯坦",
    "特克斯和凯科斯群岛",
    "图瓦卢",
    "乌干达",
    "乌克兰",
    "阿拉伯联合酋长国",
    "英国",
    "美国",
    "乌拉圭",
    "乌兹别克斯坦",
    "瓦努阿图",
    "委内瑞拉",
    "越南",
    "维尔京群岛",
    "威克岛",
    "瓦利斯和富图纳群岛",
    "西撒哈拉",
    "也门",
    "赞比亚",
    "津巴布韦"
]

pinyin_country = [
    "Āfùhàn",
    "Ā'ěrbāníyǎ",
    "Ā'ěrjílìyà",
    "Měishǔ Sàmóyǎ",
    "Āndào'ěr",
    "Āngēlā",
    "Ānguīlā Dǎo",
    "Nánjízhōu",
    "Āntíguā hé Bābùdá",
    "Āgēntíng",
    "Yàměiníyà",
    "Ālǔbā Dǎo",
    "Àodàlìyà",
    "Àodìlì",
    "Āsàibàijiāng",
    "Bāhāmǎ",
    "Bālín",
    "Mèngjiālāguó",
    "Bābāduōsī",
    "Bái'èluósī",
    "Bǐlìshí",
    "Bólìzī",
    "Bèiníng",
    "Bǎimùdà",
    "Bùdān",
    "Bōlìwéiyà",
    "Bōsīníyà hé Hēisāigēwéinà",
    "Bócíwǎnà",
    "Bāxī",
    "Yīngshǔ Yìndùyáng Lǐngdì",
    "Yīngshǔ Wéi'ěrjīng Qúndǎo",
    "Wénlái",
    "Bǎojiālìyà",
    "Bùjīnàfǎsuǒ",
    "Miǎndiàn",
    "Bùlóngdí",
    "Jiǎnpǔzhài",
    "Kāmàilóng",
    "Jiānádà",
    "Fódéjiǎo",
    "Kāimàn Qúndǎo",
    "Zhōng Fēi Gònghéguó",
    "Zhàdé",
    "Zhìlì",
    "Zhōngguó",
    "Shèngdàn Dǎo",
    "Kèlìpòdùn Dǎo",
    "Kēkēsī (Jīlín) Qúndǎo",
    "Gēlúnbǐyà",
    "Kēmóluó",
    "Gāngguǒ Mínzhǔ Gònghéguó",
    "Gāngguǒ Gònghéguó",
    "Kùkè Qúndǎo",
    "Shānhúhǎi Qúndǎo",
    "Gēsīdálíjiā",
    "Kētèdíwǎ",
    "Kèluódìyà",
    "Gǔbā",
    "Sàipǔlùsī",
    "Jiékè Gònghéguó",
    "Dānmài",
    "Jíbùtì",
    "Duōmǐníkè",
    "Duōmíngníjiā Gònghéguó",
    "Èguāduō'ěr",
    "Āijí",
    "Sà'ěrwǎduō",
    "Chìdào Jǐnèiyà",
    "Èlìtèlǐyà",
    "Àishāníyà",
    "Āisài'ébǐyà",
    "Ōuluóbā Dǎo",
    "Fúkèlán Qúndǎo",
    "Fǎluó Qúndǎo",
    "Fěijì",
    "Fēnlán",
    "Fǎguó",
    "Fǎshǔ Guīyànà",
    "Fǎshǔ Bōlìníxīyà",
    "Jiāpéng",
    "Gāngbǐyà",
    "Qiáozhìyà",
    "Déguó",
    "Jiānà",
    "Zhíbùluótuó",
    "Géluòlǐ‘èsī Qúndǎo",
    "Xīlà",
    "Gélínglán",
    "Gélínnàdá",
    "Guādéluópǔ Dǎo",
    "Guāndǎo",
    "Wēidìmǎlā",
    "Gēnxīdǎo",
    "Jǐnèiyà",
    "Jǐnèiyà-Bǐshào",
    "Guīyǎnà",
    "Hǎidì",
    "Luómǎjiàotíng (Fàndìgāngchéng)",
    "Hóngdūlāsī",
    "Xiōngyálì",
    "Bīngdǎo",
    "Yìndù",
    "Yìndùníxīyà",
    "Yīlǎng",
    "Yīlākè",
    "Ài'ěrlán",
    "Mǎ'ēn Dǎo",
    "Yǐsèliè",
    "Yìdàlì",
    "Yámǎijiā",
    "Yángmǎyán Dǎo",
    "Rìběn",
    "Zéxī Dǎo",
    "Yuēdàn",
    "Xīnhú'ān Dǎo",
    "Hāsàkèsītǎn",
    "Kěnníyà",
    "Jīlǐbāsī",
    "Kēwēitè",
    "Jí'ěrjísīsītǎn",
    "Lǎowō",
    "Lātuōwéiyà",
    "Líbānèn",
    "Láisuǒtuō",
    "Lìbǐlǐyà",
    "Lìbǐyà",
    "Lièzhīdūnshìdēng",
    "Lìtáowǎn",
    "Lúsēnbǎo",
    "Mǎqídùn",
    "Mǎdájiāsījiā",
    "Mǎlāwéi",
    "Mǎláixīyà",
    "Mǎ'ěrdàifū",
    "Mǎlǐ",
    "Mǎ'ěrtā",
    "Mǎshào'ěr Qúndǎo",
    "Mǎtíníkè Dǎo",
    "Máolǐtǎníyà",
    "Máolǐqiúsī",
    "Mǎyuētè Dǎo",
    "Mòxīgē",
    "Mìkèluóníxīyà Liánbāng",
    "Mó'ěrduōwǎ",
    "Mónàgē",
    "Měnggǔ",
    "Méngtèsāilātè",
    "Móluògē",
    "Mòsāngbǐkè",
    "Nàmǐbǐyà",
    "Nǎolǔ",
    "Nàwǎsà Dǎo",
    "Níbó'ěr",
    "Hélán",
    "Héshǔ Āndelièsī",
    "Xīn Kālǐduōníyà",
    "Xīnxīlán",
    "Níjiālāguā",
    "Nírì'ěr",
    "Nírìlìyà",
    "Niǔ'āi",
    "Nuòfúkè Dǎo",
    "Cháoxiǎn",
    "Běi Mǎlǐyànà Qúndǎo",
    "Nuówēi",
    "Āmàn",
    "Bājīsītǎn",
    "Pàláo",
    "Bānámǎ",
    "Bābùyà Xīnjǐnèiyà",
    "Xīshā Qúndǎo",
    "Bālāguī",
    "Bìlǔ",
    "Fēilǜbīn",
    "Pítèkǎi'ēn Qúndǎo",
    "Bōlán",
    "Pútáoyá",
    "Bōduōlígè",
    "Kǎtǎ'ěr",
    "Liúníwāng",
    "Luómǎníyà",
    "Éluósī",
    "Lúwàngdá",
    "Shèng Hèlèná Dǎo",
    "Shèngjīcí hé Níwéisī",
    "Shènglúxīyà Dǎo",
    "Shèng Pí'āi'ěr hé Mìkèlóng Qúndǎo",
    "Shèngwénsēntè hé Gélínnàdīngsī",
    "Sàmóyà",
    "Shèngmǎlìnuò",
    "Shèngduōměi hé Pǔlínxībǐ",
    "Shātè Ālābó",
    "Sàinèijiā'ěr",
    "Sài'ěrwéiyà hé Hēishān",
    "Sàishé'ěr Qúndǎo",
    "Sàilālì'áng",
    "Xīnjiāpō",
    "Sīluòfákè",
    "Sīluòwénníyà",
    "Suǒluómén Qúndǎo",
    "Suǒmǎlǐ",
    "Nánfēi",
    "Hánguó",
    "Xībānyá",
    "Nánshā Qúndǎo",
    "Sīlǐlánkǎ",
    "Sūdān",
    "Sūlǐnán",
    "Sīwǎ'ěrbā Qúndǎo",
    "Sīwēishìlán",
    "Ruìdiǎn",
    "Ruìshì",
    "Xùlìyà",
    "Tǎjíkèsītǎn",
    "Tǎnsāngníyà",
    "Tàiguó",
    "Dōngdìwèn",
    "Duōgē",
    "Tuōkèláo",
    "Tāngjiā",
    "Tèlìnídá hé Duōbāgē",
    "Tèluómǔlán Dǎo",
    "Túnísī",
    "Tǔ'ěrqí",
    "Tǔkùmànsītǎn",
    "Tèkèsī hé Kǎikēsī Qúndǎo",
    "Túwǎlú",
    "Wūgāndá",
    "Wūkèlán",
    "Ālābó Liánhé-qiúzhǎngguó",
    "Yīngguó",
    "Měiguó",
    "Wūlāguī",
    "Wūzībiékèsītǎn",
    "Wǎnǔ'ātú",
    "Wěinèiruìlā",
    "Yuènán",
    "Wéi'ěrjīng Qúndǎo",
    "Wēikè Dǎo",
    "Wǎlìsī hé Fùtúnà Qúndǎo",
    "Xīsāhālā",
    "Yěmén",
    "Zànbǐyà",
    "Jīnbābùwéi"
]

en_country = [
    "Afghanistan",
    "Albania",
    "Algeria",
    "American Samoa",
    "Andorra",
    "Angola",
    "Anguilla",
    "Antarctica",
    "Antigua and Barbuda",
    "Argentina",
    "Armenia",
    "Aruba",
    "Australia",
    "Austria",
    "Azerbaijan",
    "Bahamas, The",
    "Bahrain",
    "Bangladesh",
    "Barbados",
    "Belarus",
    "Belgium",
    "Belize",
    "Benin",
    "Bermuda",
    "Bhutan",
    "Bolivia",
    "Bosnia and Herzegovina",
    "Botswana",
    "Brazil",
    "British Indian Ocean Territory",
    "British Virgin Islands",
    "Brunei",
    "Bulgaria",
    "Burkina Faso",
    "Burma",
    "Burundi",
    "Cambodia",
    "Cameroon",
    "Canada",
    "Cape Verde",
    "Cayman Islands",
    "Central African Republic",
    "Chad",
    "Chile",
    "China",
    "Christmas Island",
    "Clipperton Island",
    "Cocos (Keeling) Islands",
    "Colombia",
    "Comoros",
    "Congo, Democratic Republic of the",
    "Congo, Republic of the",
    "Cook Islands",
    "Coral Sea Islands",
    "Costa Rica",
    "Cote d'Ivoire",
    "Croatia",
    "Cuba",
    "Cyprus",
    "Czech Republic",
    "Denmark",
    "Djibouti",
    "Dominica",
    "Dominican Republic",
    "Ecuador",
    "Egypt",
    "El Salvador",
    "Equatorial Guinea",
    "Eritrea",
    "Estonia",
    "Ethiopia",
    "Europa Island",
    "Falkland Islands",
    "Faroe Islands",
    "Fiji",
    "Finland",
    "France",
    "French Guiana",
    "French Polynesia",
    "Gabon",
    "Gambia",
    "Georgia",
    "Germany",
    "Ghana",
    "Gibraltar",
    "Glorioso Islands",
    "Greece",
    "Greenland",
    "Grenada",
    "Guadeloupe",
    "Guam",
    "Guatemala",
    "Guernsey",
    "Guinea",
    "Guinea-Bissau",
    "Guyana",
    "Haiti",
    "Holy See (Vatican City)",
    "Honduras",
    "Hungary",
    "Iceland",
    "India",
    "Indonesia",
    "Iran",
    "Iraq",
    "Ireland",
    "Isle of Man",
    "Israel",
    "Italy",
    "Jamaica",
    "Jan Mayen",
    "Japan",
    "Jersey",
    "Jordan",
    "Juan de Nova Island",
    "Kazakhstan",
    "Kenya",
    "Kiribati",
    "Kuwait",
    "Kyrgyzstan",
    "Laos",
    "Latvia",
    "Lebanon",
    "Lesotho",
    "Liberia",
    "Libya",
    "Liechtenstein",
    "Lithuania",
    "Luxembourg",
    "Macedonia",
    "Madagascar",
    "Malawi",
    "Malaysia",
    "Maldives",
    "Mali",
    "Malta",
    "Marshall Islands",
    "Martinique",
    "Mauritania",
    "Mauritius",
    "Mayotte",
    "Mexico",
    "Micronesia, Federated States of",
    "Moldova",
    "Monaco",
    "Mongolia",
    "Montserrat",
    "Morocco",
    "Mozambique",
    "Namibia",
    "Nauru",
    "Navassa Island",
    "Nepal",
    "Netherlands",
    "Netherlands Antilles",
    "New Caledonia",
    "New Zealand",
    "Nicaragua",
    "Niger",
    "Nigeria",
    "Niue",
    "Norfolk Island",
    "North Korea",
    "Northern Mariana Islands",
    "Norway",
    "Oman",
    "Pakistan",
    "Palau",
    "Panama",
    "Papua New Guinea",
    "Paracel Islands",
    "Paraguay",
    "Peru",
    "Philippines",
    "Pitcairn Islands",
    "Poland",
    "Portugal",
    "Puerto Rico",
    "Qatar",
    "Reunion",
    "Romania",
    "Russia",
    "Rwanda",
    "Saint Helena",
    "Saint Kitts and Nevis",
    "Saint Lucia",
    "Saint Pierre and Miquelon",
    "Saint Vincent and the Grenadines",
    "Samoa",
    "San Marino",
    "Sao Tome and Principe",
    "Saudi Arabia",
    "Senegal",
    "Serbia and Montenegro",
    "Seychelles",
    "Sierra Leone",
    "Singapore",
    "Slovakia",
    "Slovenia",
    "Solomon Islands",
    "Somalia",
    "South Africa",
    "South Korea",
    "Spain",
    "Spratly Islands",
    "Sri Lanka",
    "Sudan",
    "Suriname",
    "Svalbard",
    "Swaziland",
    "Sweden",
    "Switzerland",
    "Syria",
    "Tajikistan",
    "Tanzania",
    "Thailand",
    "Timor-Leste",
    "Togo",
    "Tokelau",
    "Tonga",
    "Trinidad and Tobago",
    "Tromelin Island",
    "Tunisia",
    "Turkey",
    "Turkmenistan",
    "Turks and Caicos Islands",
    "Tuvalu",
    "Uganda",
    "Ukraine",
    "United Arab Emirates",
    "United Kingdom",
    "United States of America",
    "Uruguay",
    "Uzbekistan",
    "Vanuatu",
    "Venezuela",
    "Vietnam",
    "Virgin Islands",
    "Wake Island",
    "Wallis and Futuna",
    "Western Sahara",
    "Yemen",
    "Zambia",
    "Zimbabwe"
]
